@@ -334,7 +334,7 @@ static void update_ssl_ctx(evutil_socket_t sock, short events, update_ssl_ctx_cb
 	UNUSED_ARG(events);
 }
 
-static void set_ssl_ctx(ioa_engine_handle e, turn_params_t *params)
+void set_ssl_ctx(ioa_engine_handle e, turn_params_t *params)
 {
 	update_ssl_ctx_cb_args_t *args = (update_ssl_ctx_cb_args_t *)turn_malloc(sizeof(update_ssl_ctx_cb_args_t));
 	args->engine = e;
@@ -1655,11 +1655,12 @@ static void setup_relay_server(struct relay_server *rs, ioa_engine_handle e, int
 			 &turn_params.stun_only,
 			 &turn_params.no_stun,
 			 &turn_params.prod,
+			 &turn_params.web_admin_listen_on_workers,
 			 &turn_params.alternate_servers_list,
 			 &turn_params.tls_alternate_servers_list,
 			 &turn_params.aux_servers_list,
 			 turn_params.udp_self_balance,
-			 &turn_params.no_multicast_peers, &turn_params.no_loopback_peers,
+			 &turn_params.no_multicast_peers, &turn_params.allow_loopback_peers,
 			 &turn_params.ip_whitelist, &turn_params.ip_blacklist,
 			 send_socket_to_relay,
 			 &turn_params.secure_stun, &turn_params.mobility,
@@ -1669,7 +1670,6 @@ static void setup_relay_server(struct relay_server *rs, ioa_engine_handle e, int
 			 allocate_bps,
 			 turn_params.oauth,
 			 turn_params.oauth_server_name,
-			 use_http,
 			 turn_params.keep_address_family);
 	
 	if(to_set_rfc5780) {
